/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

/*!
 * \brief class cyclops camera data settings
 * \author J. Locatelli
 * \date 21-11-2019
 */

#ifndef CYCLOPSDATAHEADER_H
#define CYCLOPSDATAHEADER_H

#include <Controller.h>
#include "CyclopsSetting.h"
#include "controllers/common/utilities/CountSpy.h"
#include "controllers/common/acquisition/ExperimentData.h"
#include "controllers/common/axis/AxisController.h"
#include "controllers/common/sample_environment/environment/SampleSettings.h"
#include "controllers/common/scanlegacy/ScanInfo.h"

#include "drivers/photonic/psl/PslDriver.h"

namespace cyclops {

/*!
 * \class cyclops data server path setiing
 * \brief Configure data path and name for cyclops data server
 */
class CyclopsDataHeader: public ExperimentController {

public:

	//! Type of controller
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the experiment controller
	 */
	CyclopsDataHeader(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CyclopsDataHeader();

private:

	/*!
	 * \brief Method called before changing the property value
	 * This method is called after setting configuration during the creation of controller.
	 */
	virtual void postConfiguration();

	void updateStatusMessage();

	DriverPtr<psl::PslDriver> m_CamDriver;
	ControllerPtr<acquisition::ExperimentData> m_Title;
	ControllerPtr<utilities::CountSpy> m_CountSpy;
	ControllerPtr<sample_environment::SampleSettings> m_SampleSettings;
	ControllerPtr<scan::ScanInfo> m_ScanInfo;
	ControllerPtr<CyclopsSetting> m_CyclopsSetting;
	std::vector<axis::AxisController*> m_AxisControllers;

	void createHeader();
	void create_a(std::ostream& out, const std::string& name, const std::string& value);
	void create_i(std::ostream& out, const std::string& name, int32 value, uint32 nbch);
	void create_f(std::ostream& out, const std::string& name, float64 value, uint32 nbch, uint32 nbdec);

	static const std::string SEP_VALUE;
	static const std::string SEP_PARAM;
	static const std::string END;
};

}

#endif //CYCLOPSDATAHEADER_H
