/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

/*!
 * \briefD19 Par  command
 * \author J.Locatelli
 * \date 13-10-2017
 */

#include "CyclopsFileCmd.h"
#include "../CyclopsDataPath.h"

using namespace std;

namespace cyclops {

/*
 * Constructor
 */
CyclopsFileCmd::CyclopsFileCmd(AbstractParser* aParser) :
		AbstractCmd(aParser) {
	// empty
}

/*
 * Destructor
 */
CyclopsFileCmd::~CyclopsFileCmd() {
	// empty
}

/*
 * parse
 */
void CyclopsFileCmd::parse(Items& items) throw (CannotSetValue, CommonCmdDef::BadInput) {
	CyclopsDataPath* controller = dynamic_cast<CyclopsDataPath*>(m_Parser->getControllerByType(CyclopsDataPath::TYPE));
	if (controller == NULL) {
		throw CommonCmdDef::BadInput("Controller " + CyclopsDataPath::TYPE + " not found");
	}

	++items;
	if (items.end() == false) {
		if (*items != "=") {
			controller->datapath = *items;
		}
		++items;
		if (items.end() == false) {
			if (*items != "=") {
				controller->dataname = *items;
			}
		}
		vector<CommandLineCommand> controllersToStart;
		controllersToStart.push_back(CommandLineCommand(controller));
		CommandLineManager::getInstance()->startControllers(START_COMMAND, controllersToStart, m_Parser->isSynchronized());
	}
	ostringstream buf1;
	buf1 << "Cyclops data directory : " << controller->datapath();
	m_Parser->outputText(buf1.str());
	m_Parser->outputEndl();
	ostringstream buf2;
	buf2 << "Cyclops data filename  : " << controller->dataname();
	m_Parser->outputText(buf2.str());
	m_Parser->outputEndl();
}

}
