/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

/*!
 * \brief Cyclops Par  command
 * \author J.Locatelli
 * \date 16-04-2019
 */

#include <boost/any.hpp>
#include <boost/format.hpp>
#include <boost/algorithm/string.hpp>
#include "controllers/dif/cyclops/CyclopsSetting.h"

#include "CyclopsParCmd.h"

using namespace std;
using namespace boost;

namespace cyclops {

/*
 * Constructor
 */
CyclopsParCmd::CyclopsParCmd(AbstractParser* aParser) :
		dif::DiffParCmd(aParser) {
	// empty
}

/*
 * Destructor
 */
CyclopsParCmd::~CyclopsParCmd() {
	// empty
}

/*
 * parse
 */
void CyclopsParCmd::parse(Items& items) throw (CannotSetValue, CommonCmdDef::BadInput) {
	++items;
	if (items.end() == true) {
		throw CommonCmdDef::BadInput();
	}

	// Loop for set
	while (items.end() == false) {
		ExperimentController* controller = NULL;

		/*
		 * Check For cyclops
		 */
		if ((StringUtilities::cmp(*items, "cyclops", 4) == true)) {
			++items;
			CyclopsSetting* controller = dynamic_cast<CyclopsSetting*>(m_Parser->getControllerByFunction(
					CyclopsSetting::TYPE));
			if (controller == NULL) {
				throw CommonCmdDef::BadInput("Controller " + CyclopsSetting::TYPE + " not found");
			}
			if (items.end() == false) {
				if (*items != "=") {
					controller->gain = m_Parser->cast<int32>(*items);
				}
				++items;
				if (items.end() == false) {
					if (*items != "=") {
						int32 value = m_Parser->cast<int32>(*items);
						if (value == 1) {
							controller->modeBP = true;
						} else if (value == 0) {
							controller->modeBP = false;
						} else {
							throw CommonCmdDef::BadInput("Bright Pixel correction should be 0 or 1");
						}
					}
					++items;
					if (items.end() == false) {
						if (*items != "=") {
							int32 value = m_Parser->cast<int32>(*items);
							if ((value > 0) && (value < 5)) {
								controller->mode.setpoint = value;
							} else {
								throw CommonCmdDef::BadInput("Acquisition mode should be 1, 2, 3 or 4");
							}
						}
					}
				}
			}
			ostringstream buf1;
			buf1 << "Intensifier gain: " << controller->gain();
			m_Parser->outputText(buf1.str());
			m_Parser->outputEndl();
			ostringstream buf2;
			buf2 << "Bright Pixel correction 0/1: " << controller->modeBP();
			m_Parser->outputText(buf2.str());
			m_Parser->outputEndl();
			ostringstream buf3;
			buf3 << "Acq mode: 1=standard, 2=average, 3=summation, 4=accumulation: " << controller->mode.setpoint();
			m_Parser->outputText(buf3.str());
			m_Parser->outputEndl();
		} else {
			--items;
			DiffParCmd::parse(items);
		}

		m_Parser->outputEndl();

		if (items.end() != true) {
			++items;
		}
	}
}

}
