/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef DIELECTRICS_RUNSPECTRUMS_H
#define DIELECTRICS_RUNSPECTRUMS_H

#include "Spectrums.h"

namespace dielectrics {

class RunSpectrums : public Spectrums,
						public controller::Stoppable,
						public controller::Raz {

public:
	//! Type of controller
	static const std::string TYPE;

	RunSpectrums(const std::string& name);
	virtual ~RunSpectrums();

	virtual void postConfiguration();

	virtual void start();
	virtual void stop();
	virtual void raz();

	void updateApplicationState();
	void updateState();
	void updateN();
	void updateTime();
	void updateRun();

	Property<double> fr;
	Property<double> frMin;
	Property<double> frMax;
	Property<int32, SETPOINT> N;
	Property<double, SETPOINT> time;
	Property<std::string> comment;
	Property<int32> actualRun;

protected:
	void logRunNumbers(LogStream& logStream);
};

}

#endif
