/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "CAENSy2527BoardDriver.h"

#include "drivers/global/DriversCommands.h"
#include "controllers/common/detector_hv/DetectorHVCommon.h"
#include "CAENSy2527Def.h"
#include "PerfectCAENSy2527BoardDriver.h"
#include "RealCAENSy2527BoardDriver.h"

using namespace std;

namespace caen_sy2527 {

const std::string CAENSy2527BoardDriver::TYPE = "caen_sy2527_board";

const std::string CAENSy2527BoardDriver::SWITCH_ON_COMMAND = "switch_on";
const std::string CAENSy2527BoardDriver::SWITCH_OFF_COMMAND = "switch_off";

/*
 * Constructor
 */
CAENSy2527BoardDriver::CAENSy2527BoardDriver(const string& name) : DetectorHVCommon(name) {

	registerStates(new RealCAENSy2527BoardDriver(this), new PerfectCAENSy2527BoardDriver(this), new PerfectCAENSy2527BoardDriver(this));

	deviceType = LEAF_DEVICE_TYPE_DEVICE_CONTAINER;

	// Init the device command list
	initCommand(driver::INIT_COMMAND);
	initCommand(driver::READ_INFOS_COMMAND);

	// Init function
	registerParentFunction(CAENSY2527_FUNCTION);
	registerFunction(NONE_FUNCTION);

//	registerRefresher(power, &CAENSy2527BoardDriver::refreshPowerProperty, this);

	/*
	 * Register the Spy and Observer commands necessary to do the updates.
	 */
	registerSpyCommand(driver::READ_COMMAND, 2);
	registerSpyCommand(driver::STATUS_COMMAND, 2);
	registerObserverCommand(driver::READ_COMMAND, 20);
	registerObserverCommand(driver::STATUS_COMMAND, 20);
}

/*
 * Destructor
 */
CAENSy2527BoardDriver::~CAENSy2527BoardDriver()
{
  // Empty
}

/*
 * execute
 */
void CAENSy2527BoardDriver::execute(const string& aCommand) {

	if ((aCommand != driver::STOP_COMMAND) &&
			(aCommand != driver::STATUS_COMMAND) &&
			(aCommand != driver::READ_COMMAND)) {
		sendProgressEvent(PROGRESSION_UNKNOWNSTATE_DEVICE_CONTAINER);
	}

	CAENSy2527BoardState* currentState = dynamic_cast<CAENSy2527BoardState *> (getCurrentState());

	// Check command
	if (aCommand == driver::INIT_COMMAND) {
		currentState->init();
	} else if (aCommand == driver::READ_COMMAND) {
		currentState->read();
	} else if (aCommand == driver::READ_INFOS_COMMAND) {
		currentState->readParam();
	} else if (aCommand == driver::START_COMMAND) {
		startActivated = true;
		m_startVoltage = voltage();
		currentState->start();
	} else if (aCommand == driver::STOP_COMMAND) {
		startActivated = false;
		currentState->stop();
	} else if (aCommand == driver::STATUS_COMMAND) {
		currentState->readStatus();
	} else if (aCommand == DetectorHVCommon::SWITCH_ON_COMMAND) {
		currentState->powerOn();
	} else if (aCommand == DetectorHVCommon::SWITCH_OFF_COMMAND) {
		currentState->powerOff();
	} else {
		//Error bad command
		//Todo , normaly it will be detect it device action driver
	}
}
/*
void CAENSy2527BoardDriver::refreshPowerProperty(int32 index, string aValue) throw (CannotSetValue) {

	power.set(index, aValue);
	cout << "Got: " << aValue << endl;
}
*/
}
