/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "PerfectCAENSy2527BoardDriver.h"

#include "drivers/global/DriversCommands.h"
#include "CAENSy2527BoardDriver.h"
#include "CAENSy2527Def.h"
#include "CAENSy2527Driver.h"

namespace caen_sy2527 {

/*
 * Constructor
 */
PerfectCAENSy2527BoardDriver::PerfectCAENSy2527BoardDriver(CAENSy2527BoardDriver* owner) :
	CAENSy2527BoardState(owner) {
}

/*
 * Destructor
 */
PerfectCAENSy2527BoardDriver::~PerfectCAENSy2527BoardDriver() {

}

/*
 * init
 */
void PerfectCAENSy2527BoardDriver::init() {

	readParam();
	read();
	readStatus();
	owner()->commandProgression = PROGRESSION_END_DEVICE_CONTAINER;
}

/*
 * readStatus
 */
void PerfectCAENSy2527BoardDriver::readStatus() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->readStatus(owner());
}

/*
 * read
 */
void PerfectCAENSy2527BoardDriver::read() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->read(owner());
}

/*
 * readParam
 */
void PerfectCAENSy2527BoardDriver::readParam() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->readParam(owner());
}

/*
 * writeParam
 */
void PerfectCAENSy2527BoardDriver::writeParam() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->writeParam(owner());
}

/*
 * start
 */
void PerfectCAENSy2527BoardDriver::start() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->writeParam(owner());
	driver->start(owner());
}

/*
 * stop
 */
void PerfectCAENSy2527BoardDriver::stop() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->stop(owner());
}

/*
 * powerOn
 */
void PerfectCAENSy2527BoardDriver::powerOn() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->powerOn(owner());
}

/*
 * powerOff
 */
void PerfectCAENSy2527BoardDriver::powerOff() {

	CAENSy2527Driver* driver = dynamic_cast<CAENSy2527Driver *> (owner()->getParent());
	driver->powerOff(owner());
}

}
