/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef PERFECTCADARACHEACQDRIVER_H
#define PERFECTCADARACHEACQDRIVER_H

#include <drivers/ioxos/cadaracheacq/CadaracheAcqState.h>

namespace cadaracheacq {

/*!
 * \class PerfectCadaracheAcqDriver
 * \brief Perfect implementation class for the Cadarache device driver
 *
 * This class is a perfect implementation of StartStop device driver.
 * On start command, all actual values become target's ones.
 */
class PerfectCadaracheAcqDriver: public CadaracheAcqState {

public:

	/*!
	 * \brief Constructor
	 * \param[in] owner The device driver main class link
	 */
	PerfectCadaracheAcqDriver(CadaracheAcqDriver* owner);

	/*!
	 * \brief Destructor
	 */
	virtual ~PerfectCadaracheAcqDriver();

	/*!
	 * \brief Init command implementation
	 */
	virtual void init();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus();

	/*!
	 * \brief Start command implementation
	 */
	virtual void start();

	/*!
	 * \brief Read command implementation
	 */
	virtual void read();

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead();

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop();

	/*!
	 * \brief Pause command implementation
	 */
	virtual void pause();

	/*!
	 * \brief Resume command implementation
	 */
	virtual void resume();

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos();

	/*!
	 * \brief Write para command implementation
	 */
	virtual void writeParam();

	/*!
	 * \brief Read par command implementation
	 */
	virtual void readParam();

	/*!
	 * \brief Start command implementation
	 */
	virtual void clear();
};

}
#endif //PERFECTCADARACHEDRIVER_H
